#
# spec file for package python-narwhals
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-narwhals
Version:        1.46.0
Release:        1.1
Summary:        Extremely lightweight compatibility layer between dataframe libraries
License:        MIT
URL:            https://github.com/narwhals-dev/narwhals
Source:         https://files.pythonhosted.org/packages/source/n/narwhals/narwhals-%{version}.tar.gz
BuildRequires:  python-rpm-macros
BuildRequires:  fdupes
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
# Test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytest-env}
BuildRequires:  %{python_module pytest-randomly}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pandas >= 1.1.3}
BuildRequires:  %{python_module dask >= 2024.8}
BuildRequires:  %{python_module dask-dataframe >= 2024.8}
BuildRequires:  %{python_module pyarrow >= 11.0.0}
# optional dependencies
Suggests:       python-pandas >= 1.1.3
Suggests:       python-dask >= 2024.8
Suggests:       python-dask-dataframe >= 2024.8
Suggests:       python-pyarrow >= 11.0.0

BuildArch:      noarch
%python_subpackages

%description
Extremely lightweight and extensible compatibility layer between
dataframe libraries!

%prep
%autosetup -p1 -n narwhals-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Dependencies not available in openSUSE
donttest="polars or ibis or duckdb or sqlframe"
%pytest -k "not ($donttest)"

%files %{python_files}
%doc README.md
%license LICENSE.md
%{python_sitelib}/narwhals
%{python_sitelib}/narwhals-%{version}.dist-info

%changelog
* Mon Jul 14 2025 Dirk Müller <dmueller@suse.com>
- update to 1.46.0:
  * refactor: Cache, reuse `Implementation._backend_version`
  * enh!: simplify exceptions, consistently raise
    InvalidOperationError instead of
    ShapeError/OrderDependentExprError/LengthChangingExprError
  * feat: Add `Expr.dt.offset_by()`
  * enh: allow for `over(order_by=...)` for `rank`
  * fix: Respect session time zone when casting to `Datetime` for
    PySpark
  * enh: Support casting to Duration, and Datetime with different
    units, for DuckDB
  * feat: Add support for `quantile` and `ewm_mean` in over
    context
  * feat: Support `DataFrame().lazy("ibis")`
  * chore: xfail cudf offset_by
  * ci: cudf tests fixup
  * ci: unxfail truncate tests for pyspark by checking local
    results
  * fix: type annotation default for `named: Literal[False]` was
    missing in `DataFrame.iter_rows`
  * refactor: Cache, reuse `Implementation._backend_version`
* Sat Jul  5 2025 Dirk Müller <dmueller@suse.com>
- update to 1.45.0:
  * feat: Add `Expr|Series.str.to_date`
  * feat: add `ignore_nulls` to `any_horizontal` and
    `all_horizontal`
  * feat: Add `order_by` option in `with_row_index` method
  * patch: Preserve pandas "pyarrow" dtype_backend in
    `str.to_datetime`
  * fix: zfill for old polars and pyarrow versions
  * fix: ensure `fill_null` doesn't silently downcast for pandas
    per-3.0
  * test: Suppress `NotImplementedError` for `cuDF`
  * test: xfail floordiv polars on GPU engine
  * ci: Fail polars 0.20.6 in floordiv by zero
  * ci: use try_divide in PySpark for division
  * test: div by zero returns nan
  * chore: share binary comparisons between duckdb/ibis/spark
  * typing: Return `Self` whenever possible
  * ci: pin sqlglot, use different cache_suffixes for different
    jobs
  * chore: Add pandas-like `import_array_module` util function
  * chore: Add `LazyExprNamespace`
  * ci: fixup old versions for floordiv test
- update to 1.44.0:
  * fix, perf: avoid np.repeat for broadcasting
  * feat: Add support for `Expr.str.zfill`
  * fix: Set Ibis time_unit and time_zone for Datetime dtype
    conversion
  * fix: raise NotImplementedError instead of returning it
  * fix, perf: avoid np.repeat for broadcasting
  * fix(typing): Resolve intermittent `*GroupBy` variance issue
  * fix: ensure `generate_temporary_column_name` result always
    starts with character
* Thu Jun 19 2025 Daniel Garcia <daniel.garcia@suse.com>
- Initial version 1.43.1
